@@ -5,9 +5,7 @@ from pytest import mark
 from requests_mock import Mocker
 
 from fuzzing_cli.cli import cli
-from fuzzing_cli.fuzz.faas import FaasClient
 from fuzzing_cli.fuzz.rpc import RPCClient
-from fuzzing_cli.fuzz.run import IDE
 from tests.common import write_config
 
 REFRESH_TOKEN_MALFORMED_ERROR = (
@@ -15,6 +13,16 @@ REFRESH_TOKEN_MALFORMED_ERROR = (
 )
 
 
+class ArtifactMock:
+    def __init__(self, *args, **kwargs):
+        self.sources = {}
+        self.contracts = {}
+
+    @classmethod
+    def get_name(cls):
+        return "hardhat"
+
+
 class TestArtifacts:
     def __init__(self, *args, **kwargs):
         pass
@@ -38,8 +46,10 @@ def test_no_keys(tmp_path, truffle_project):
 
 @patch.object(RPCClient, attribute="contract_exists", new=Mock(return_value=True))
 @patch.object(RPCClient, attribute="get_seed_state", new=Mock(return_value={}))
-@patch(target="fuzzing_cli.fuzz.run.determine_ide", new=Mock(return_value=IDE.HARDHAT))
-@patch(target="fuzzing_cli.fuzz.run.HardhatJob", new=MagicMock())
+@patch(
+    target="fuzzing_cli.fuzz.ide.repository.IDERepository.detect_ide",
+    new=Mock(return_value=ArtifactMock),
+)
 @patch(target="fuzzing_cli.fuzz.run.FaasClient", new=MagicMock())
 @mark.parametrize("in_config,", [False, True])
 @mark.parametrize("key_type,", ["api_key", "refresh_token"])
@@ -68,8 +78,10 @@ def test_provide_api_key(in_config: bool, key_type: str, tmp_path, truffle_proje
 
 @patch.object(RPCClient, attribute="contract_exists", new=Mock(return_value=True))
 @patch.object(RPCClient, attribute="get_seed_state", new=Mock(return_value={}))
-@patch(target="fuzzing_cli.fuzz.run.determine_ide", new=Mock(return_value=IDE.HARDHAT))
-@patch(target="fuzzing_cli.fuzz.run.HardhatJob", new=MagicMock())
+@patch(
+    target="fuzzing_cli.fuzz.ide.repository.IDERepository.detect_ide",
+    new=Mock(return_value=ArtifactMock),
+)
 @patch(target="fuzzing_cli.fuzz.run.FaasClient", new=MagicMock())
 @mark.parametrize(
     "refresh_token",
@@ -107,8 +119,10 @@ def test_wrong_refresh_token(refresh_token: str, tmp_path):
         }
     ),
 )
-@patch(target="fuzzing_cli.fuzz.run.determine_ide", new=Mock(return_value=IDE.HARDHAT))
-@patch(target="fuzzing_cli.fuzz.run.HardhatJob", new=Mock(wraps=TestArtifacts))
+@patch(
+    target="fuzzing_cli.fuzz.ide.repository.IDERepository.detect_ide",
+    new=Mock(return_value=ArtifactMock),
+)
 @mark.parametrize("return_error,", [True, False])
 def test_retrieving_api_key(requests_mock: Mocker, return_error: bool, tmp_path):
     requests_mock.real_http = True
